<section class="breadcrumbs">
  <div class="container">

    <div class="d-flex justify-content-between align-items-center">
      <h2>{{ breadcrumb.title|lower|capfirst }}</h2>
      <ol>
        <li><a href="{% url 'bocor:home' %}">Home</a></li>
        <li>{{ breadcrumb.title|lower|capfirst }}</li>
      </ol>
    </div>
  </div>
</section>
