{% extends 'bocor/index.html' %}
{% load static %}

{% block content %}
  <main id="main">

    {% include 'bocor/breadcrumb.html' %}

    <section class="inner-page">
      {% privacy privacy.company_name privacy.sdate privacy.owner privacy.phone privacy.email %}
    </section>

  </main><!-- End #main -->
{% endblock content %}